# coding: utf-8

"""
    TrueLayer Resource API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v1.0
    Contact: rienafairefr@gmail.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import truelayer
from truelayer.models.account_number import AccountNumber  # noqa: E501
from truelayer.rest import ApiException

class TestAccountNumber(unittest.TestCase):
    """AccountNumber unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test AccountNumber
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = truelayer.models.account_number.AccountNumber()  # noqa: E501
        if include_optional :
            return AccountNumber(
                iban = '0', 
                number = '0', 
                sort_code = '0', 
                swift_bic = '0'
            )
        else :
            return AccountNumber(
        )

    def testAccountNumber(self):
        """Test AccountNumber"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()
