# coding: utf-8

"""
    TrueLayer Authtentication

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v1.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import truelayer.auth
from truelayer.auth.models.provider import Provider  # noqa: E501
from truelayer.auth.rest import ApiException

class TestProvider(unittest.TestCase):
    """Provider unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test Provider
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = truelayer.auth.models.provider.Provider()  # noqa: E501
        if include_optional :
            return Provider(
                country = '0', 
                display_name = '0', 
                logo_url = '0', 
                provider_id = '0', 
                scopes = [
                    '0'
                    ]
            )
        else :
            return Provider(
        )

    def testProvider(self):
        """Test Provider"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()
